Module observer

Module observer 

Observer trait and function implementations.

Structs

RequestEndData
Request end arguments container
RequestStartData
Request start arguments container

Traits

Observer
An Observer is notified before a request is passed for processing, and after processing into a response. Use case could be logging before and after request: